<?php
/**
 * Content/HTML Generation, Output Functionality
 * 
 * This file contains useful functions for generating HTML and 
 * output for the user. Modify and add functions on your local machine and 
 * for individual website needs. Only add universally useful functions
 * back in the shared version of this file.
 * 
 * @package wwm_lib_php
 * @version 0.1
 * @author Daniel Roestorf <danielroestorf@gmail.com>
 * @copyright West World Media ©2013
 */
	 
/** Includes required for this file to function. */
require_once 'inc.lib.db.php';
require_once 'inc.lib.query.php';
	
/**************************************************
 * Content Building Functions
 **************************************************/
 
 
 	
	/**
	 * Extract list of theatre features from semicolon delimited string
	 * 
	 * @param $features
	 *
	 * @return String $html
	 */
	 function html_house_features($string) {
		 $html = "";
		 
		 //split the features string into an array
		 $features = array();
		 $features = split(';', $string);
		 
		 //loop through the array and output the items
		 foreach ($features as $f) {
			 
			 //trim the string
			 $f = trim($f);
			 
			 //only print out non empty string
			 if ($f != "") {
			 	$html .= "<span class='feature'>$f</span>";
			 }
		 }
		 
		 return $html;
		 $features = NULL;
	 }
	 
	/**
	 * Build list of houses in a chain for navigation drop-down.
	 * 
	 * @param $chain_id
	 * @return String $html
	 */
	function html_chain_houses_nav($db, $chain_id, $site_id) {
		$html = "";
		$hs = chain_get_houses($db, $chain_id, $site_id);
		foreach ($hs as $h) {
			
			//setup variables
			$house_id = fix_movie_id($h['house_id']);
			$name = trim($h['name']);
			$url_name = url_name($name) . "-Showtimes";
			$city = trim($h['city']);
			$state = trim($h['state']);
			
			//write out HTML
			$html .= "<li><a href='/location/$house_id/$url_name'>$name, $city, $state</a></li>\r";
		}
		
		return $html;
		$hs = NULL;
	}
	
	/**
	 * Build now playing list for navigation drop down.
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $date YYYY-MM-DD
	 * @return String $html
	 */
	function html_house_now_playing_nav($db, $house_id, $date) {
		$html = "";
		$ms = house_get_now_playing($db, $house_id, $date);
		foreach ($ms as $m) {
			
			//setup variables
			$movie_id = fix_movie_id($m['movie_id']);
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			
			//write out HTML
			$html .= "<li><a href='/movie/$movie_id/$url_name'>$name$attribute</a></li>\r";
		}
		
		return $html;
		$ms = NULL;
	}
	
	/**
	 * Build list of houses for Location Page
	 * 
	 * @param $chain_id
	 * @return String $html
	 */
	function html_houses_page($db, $chain_id, $site_id) {
		$html = "";
		$count = 1;
		$hs = chain_get_houses($db, $chain_id, $site_id);
		foreach ($hs as $h) {
			
			//setup variables
			$class= "";
			$house_id = fix_movie_id($h['house_id']);
			$name = trim($h["name"]);
			$url_name = url_name($name) . "-Showtimes";
			$photo = fxp_build_house_photo_url($site_id, $h["PhotoUrl"]);
			$address = trim($h["address"]) . "<br>" . trim($h["city"]) . ", " . trim($h["state"]) . " " . trim($h["zip"]);
			$city = trim($h["city"]) . ", " . get_state_name(trim($h["state"]));
			$phone = build_phone_number(trim($h["phone1"]));
			$movieline = build_phone_number(trim($h["movieline"]));
			$email = strtolower(trim($h["email"]));
			$photo = fxp_build_house_photo_url($site_id, $h["photourl"]);
			
			//add a class to the the middle box of the 3-up format
			if ($count == 1) {
				$class = 'first';
			} elseif ($count == 3) {
				$class = 'last';
			}
			
			//write out HTML
			$html .= "<div id='theaterBox' class='$class fade'>
						 <a href='/location/$house_id/$url_name' class='nolink'>
					  	 <h4>$name</h4>
					  	 <div class='image_container'>
					  	 	<img src='$photo' />
					  	 </div>
					  	 <p>$address<br />$movieline</p></a>
					  </div>";
			
			//reset the counter when desired number hit
			if ($count == 3) {
				$count = 1;
			} else {
				$count++;
			}
			
		}
		
		return $html;
		$hs = NULL;
	}	
	/**
	 * Build list of showdates for a house in JSON format
	 * for use with jQuery datepicker
	 *
	 * @param $db
	 * @param $house_id
	 * @param $date
	 * @return String $json
	 */
	function html_house_get_json_showdates($db, $house_id, $date) {
		$json = "";
		$dates = house_get_showdates($db, $house_id, $date);

		foreach ($dates as $d) {
			$json .= '"' . date('n/j/Y', strtotime($d)) . '",';
		}

		return $json;
		$dates = NULL;
	}
	
	/**
	 * Build now playing list for navigation drop down.
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $date YYYY-MM-DD
	 * @return String $html
	 */
	function html_chain_now_playing_nav($db, $site_id, $date) {
		$html = "";
		$ms = chain_get_now_playing($db, $site_id, $date);

		foreach ($ms as $m) {
			
			//setup variables
			$movie_id = fix_movie_id($m['movie_id']);
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			
			//write out HTML
			$html .= "<li><a href='/movie/$movie_id/$url_name'>$name</a></li>\r";
		}
		
		return $html;
		$ms = NULL;
	}
	
	/**
	 * Build list of houses in a chain for navigation drop-down.
	 * 
	 * @param $chain_id
	 * @return String $html
	 */
	function html_write_houses_nav($db, $chain_id, $site_id) {
		$html = "";
		
		//get the HTML and write to a file
		$html .= html_chain_houses_nav($db, $chain_id, $site_id);
		file_put_contents("data/houses_nav.html", $html);
	}
	
	/**
	 * Build list of houses in a chain for navigation drop-down.
	 *
	 * @param $db
	 * @param $chain_id
	 * @param $site_id
	 * @param $value
	 *
	 * @return String $html
	 */
	function html_write_houses_select($db, $chain_id, $site_id, $value) {
		$html = "";
		
		//get the HTML and write to a file
		$html .= html_chain_houses_select($db, $chain_id, $site_id, $value);
		file_put_contents("data/houses_select.html", $html);
	}
	
	/**
	 * Build list of movies in a chain for navigation drop-down.
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $date
	 *
	 * @return String $html
	 */
	function html_write_movies_select($db, $site_id, $date) {
		$html = "";
		
		//get the HTML and write to a file
		$html .= html_site_movies_select($db, $site_id, $date);
		file_put_contents("data/movies_select.html", $html);
	}
	
	/**
	 * Build list of houses in a chain for select drop-down.
	 * 
	 * @param $chain_id
	 * @return String $html
	 */
	function html_chain_houses_select($db, $chain_id, $site_id, $value) {
		$html = "";
		$hs = chain_get_houses($db, $chain_id, $site_id, $value);
		foreach ($hs as $h) {
			
			//setup variables
			$house_id = fix_movie_id($h['house_id']);
			$name = trim($h['name']);
			$url_name = url_name($name) . "-Showtimes";
			$city = trim($h['city']);
			$state = trim($h['state']);
			
			if ($value == "name") {
				$opt_value = "$name";
			} else {
				$opt_value = $house_id;
			}
									
			//write out the theater
			$html .= "<option value='/location/$house_id/$url_name'>$name, $city, $state</option>\r";
		}
		
		return $html;
		$hs = NULL;
	}

	
	/**
	 * Write out HTML for movie carousel.
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $date
	 * @param $type
	 * @param $choice_id (optional)
	 *
	 * @return String $html
	 */
	function html_write_carousel($db, $site_id, $date, $type, $choice_id) {
		$html = "";
		
		//get the HTML and write to a file
		$html .= html_get_carousel_movies($db, $site_id, $date, $type, $choice_id);
		file_put_contents("data/carousel_$type.html", $html);
	}
	
	/**
	 * Writes out a static HTML page for the movies drop-down
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $site_id
	 * @param $date YYYY-MM-DD
	 * @return Outputs string $html to a file
	 */
	function html_write_movies_nav($db, $site_id, $choice_id, $date) {
		$html = '';
		
		//get the HTML and write to a file
		$html .= "<li class='subHeader'>Now Playing</li>\r\n";
		$html .= html_chain_now_playing_nav($db, $site_id, $date);
		$html .= "<li class='subHeader'>Coming Soon</li>\r\n";
		$html .= html_coming_soon_nav($db, $site_id, $choice_id);
		
		file_put_contents("data/movies_nav.html", $html);
    }
    
    /**
	 * Writes out a static HTML content for homepage slider
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $category
	 * 
	 * @return Outputs string $html to a file
	 */
	function html_write_slider($db, $site_id, $category) {
		$html = '';
		
		//get the HTML and write to a file
		$html .= html_fxp_slider_images($db,$site_id, $category);
		
		file_put_contents("data/slider_$category.html", $html);
		}
		
      /**
	 * Writes out a static HTML content for homepage slider
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $category
	 * 
	 * @return Outputs string $html to a file
	 */
	function html_write_slick_slider($db, $site_id, $category) {
		$html = '';
		
		//get the HTML and write to a file
		$html .= html_fxp_slick_slider_images($db,$site_id, $category);
		
		file_put_contents("data/slider_$category.html", $html);
    }  
	/**
	 * Writes out a static HTML content for homepage slider
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $category
	 * 
	 * @return Outputs string $html to a file
	 */
	function html_write_popup($db, $site_id) {
		$html = '';
		
		//get the HTML and write to a file
		$html .= html_fxp_popup_images($db,$site_id);
		
		file_put_contents("data/popup.html", $html);
	}      
	/**
	 * Build Facebook Open Graph tags for a movie
	 * 
	 * @param $site_name
	 * @param $arr
	 * @return String $html
	 */
	function html_facebook_movie_tags($site_name, $arr) {
		
		$html =  "\r
		          <!-- Facebook Open Graph -->
				  <meta property='og:site_name' content='$site_name'/>
				  <meta property='og:type' content='website' />
				  <meta property='og:image' content='" . build_poster_url(fix_movie_id($arr["movie_id"]), $arr["hiphotos"], 'high') . "' />
				  <meta property='og:title' content='" . fix_movie_name($arr["name"]) . " Trailer & Info | $site_name' />
				  <meta property='og:url' content='http://" . $_SERVER[HTTP_HOST] . $_SERVER[REQUEST_URI] . "'/>
				  <meta property='og:description' content='" . str_replace("'", "''", strip_tags($arr["capsule"])) . "'/>
				  \r";
		return $html;
	}
	
	/**
	 * Build Facebook Open Graph tags for a theater
	 * 
	 * @param $site_name
	 * @param $arr
	 * @return String $html
	 */
	function html_facebook_theater_tags($site_name, $arr) {
		
		$html =  "\r
		          <!-- Facebook Open Graph -->
				  <meta property='og:site_name' content='$site_name'/>
				  <meta property='og:type' content='website' />
				  <meta property='og:image' content='" . fxp_build_house_photo_url($arr["siteid"], $arr["PhotoUrl"]) . "' />
				  <meta property='og:title' content='" . $arr["name"] . " Showtimes | $site_name' />
				  <meta property='og:url' content='http://" . $_SERVER[HTTP_HOST] . $_SERVER[REQUEST_URI] . "'/>
				  <meta property='og:description' content='" . trim($arr["address"]) . ", " . trim($arr["city"]) . ", " . trim($arr["state"]) . " " . trim($arr["zip"]) . "'/>
				  \r";
		return $html;
	}

	
	/**
	 * Build now playing boxes for main movies page
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $date YYYY-MM-DD
	 * @return String $html
	 */
	function html_chain_now_playing_page($db, $site_id, $date) {
		$html = "";
		$count = 1;
		$data = chain_get_now_playing($db, $site_id, $date);
		foreach ($data as $m) {
			
			//setup variables
			$class = "";
			$attribute = "";
			$movie_id = fix_movie_id($m["movie_id"]);
			$name = fix_movie_name($m["name"]);
			$url_name = url_name($name) . "-Trailer-and-Info";
			$poster = ($m['posterImage'] != '') ? fxp_build_poster_url($site_id, $m['posterImage']) : build_poster_url($movie_id, $m['hiphotos']);
			
			
			
			 //if 3D, add attribute span
			 if (stripos($name,'3D') > 0) {
				 $attribute = "<span>IN 3D</span>";
			 }
			 
			  //if IMAX, add attribute span
			 if (stripos($name,'IMAX') > 0) {
				 $attribute = "<span>IN IMAX</span>";
			 }
			
			//add a class to the the middle box of the 3-up format
			if ($count == 1) {
				$class = 'first';
			} elseif ($count == 4) {
				$class = 'last';
			}


			$html .= "<div id='movieBox' class='$class hvr-bob'>
						<a href='/movie/$movie_id/$url_name'>
							
							<img src='$poster' />
							$attribute
						</a>
					</div>";
			$count++;
			
			//reset the counter when desired number hit
			if ($count == 4) {
				$count = 1;
			} else {
				$count++;
			}
		}
		
		return $html;
		$data = NULL;
	}
	
	/**
	 * Build coming soon boxes for main movies page
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $date YYYY-MM-DD
	 * @return String $html
	 */
	function html_chain_coming_soon_page($db, $site_id, $choice_id) {
		$html = "";
		$count = 1;
		$data = fxp_get_coming_soon($db, $site_id, $choice_id);
		foreach ($data as $m) {
			
			//setup variables
			$class = "";
			$movie_id = fix_movie_id($m["movie_id"]);
			$name = fix_movie_name($m["name"]);
			$name_encoded = str_replace("'", "''", $name);
			$url_name = url_name($name) . "-Trailer-and-Info";
			$release = ($m['release_tbd'] == '1') ? 'TBD' : date('F jS, Y', strtotime($m["release"]));
			$poster = ($m['posterImage'] != '') ? fxp_build_poster_url($site_id, $m['posterImage']) : build_poster_url($movie_id, $m['hiphotos']);
			
			//shorten the name if over 19 characters
			if (strlen($name) > 19) {
				$name = substr($name, 0, 19) . "...";
			}
			
			//add a class to the the middle box of the 3-up format
			if ($count == 1) {
				$class = 'first';
			} elseif ($count == 5) {
				$class = 'last';
			}
			
			$html .= "<div id='movieBoxCS' $mid_class class='hvr-bob' >
						<a href='/movie/$movie_id/$url_name'>
							<img src='$poster' />
							<h5>$release</h5>
						</a>
					</div>";
					
			$count++;
			
			//reset the counter when desired number hit
			if ($count == 5) {
				$count = 1;
			} else {
				$count++;
			}
		}
		
		return $html;
		$data = NULL;
	}
	
	/**
	 * Write out list of FXP slider images
	 * 
	 * @param $site_id
	 * @param $db
	 * @return String $html
	 */
	function html_fxp_slider_images($db,$site_id, $category) {
		$html = "";
		$carousel = fxp_get_carousel($db, $site_id, $category);
	
		foreach($carousel as $c) {
			$image = $c['image'];
			$url = $c['url'];
			$target = $c['target'];
			$caption = trim($c['caption']);
			
			//Wrap the image in <a> tags if there was a URL entered
			$html .= '<div data-thumb="' . $image . '" data-src="' . $image  . '" data-link="' . $url . '" data-target="' . $target . '">';
			
			//if there is caption text, add it
			if (trim($caption) != "") {
				$html .= '<div class="camera_caption"><span class="captiontext_full">' . $caption . '</span></div>';
			}
			
			//Finish Slide
			$html .= '</div>';
			
		}
		return $html;
	}

		/**
	 * Write out list of FXP slider images
	 * 
	 * @param $site_id
	 * @param $db
	 * @return String $html
	 */
	function html_fxp_slick_slider_images($db,$site_id, $category) {
		$html = "";
		$carousel = fxp_get_carousel($db, $site_id, $category);
	
		foreach($carousel as $c) {
			$image = $c['image'];
			$url = $c['url'];
			$target = $c['target'];
			$caption = trim($c['caption']);
			$alt = trim($c['alt']);
			

			$slide_html = '
				<div class="slider__block">
					<img src="' . $image . '" class="slider__image" alt="' . $alt . '"/>
				</div>
			';

			if ($url != '') {
				$slide_html = '<a href="' . $url . '">' . $slide_html . '</a>';
			}

			$html .= $slide_html;
			
		}
		$html = '<div class="slider">' . $html . '</div>';
		return $html;
	}

	/**
	 * 
	 */
	function html_fxp_popup_images($db,$site_id) {
		$html = "";
		$carousel = fxp_get_carousel($db, $site_id, 'popup');
		if (count($carousel) == 0) {
			return $html;
		}
		$image = $carousel[0]['image'];
		$url = $carousel[0]['url'];
		$alt = trim($carousel[0]['alt']);

		$html = '
			<img src="' . $image . '" class="slider__image" alt="' . $alt . '"/>
		';
		if ($url != '') {
			$html = '<a href="' . $url . '">' . $html . '</a>';
		}

		return $html;
	}
	
	/**
	 * Build carousel poster images and write them to a file.
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $site_id
	 * @param $date
	 * @param $type
	 * @param $choice_id (optional)
	 *
	 * @return String $html
	 */
	function html_get_carousel_movies($db, $site_id, $date, $type, $choice_id) {
		$html = "";
		
		//now ppaying or coming soon?
		if ($type == "np") {
			$ms = chain_get_now_playing($db, $site_id, $date);
		} else {
			$ms = fxp_get_coming_soon($db, $site_id, $choice_id);
		}
						
		foreach ($ms as $m) {
			
			//buildvariables
			$tickets = "";
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			$mpaa = trim($m['mpaa']);
			$id = fix_movie_id($m['movie_id']);
			$poster = ($m['posterImage'] != '') ? fxp_build_poster_url($site_id, $m['posterImage']) : build_poster_url($id, $m['hiphotos'], '');
			$trailer_url = build_trailer_url($id, $m["videos"]);
			$attributes = movie_get_attributes($name);
			
			//tix available?
			if ($type == "cs" && $m['showdate'] != "") {
				$tickets = "Tickets Available";
			}
			
			//write out carousel HTML
			$html .= "<div class='cimg hvr-bob'>
						  <a href='/movie/$id/$url_name'>
						  <img src='$poster' />";
			if ($tickets != "") {
				$html .= "<div class='tix-available'>$tickets</div>";
			}
			if ($attributes != "") {
				$html .= "<div class='attribute'>$attributes</div>";
			}
			
			$html .= " </div>";
		}
				
		$ms = null;
		return $html;
	}

	
	/**
	 * Build now playing list for carousel poster images.
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $date YYYY-MM-DD
	 * @return String $html
	 */
	function html_chain_now_playing_posters($db, $chain_id, $date) {
		$html = "";
		$ms = chain_get_now_playing($db, $chain_id, $date);
		foreach ($ms as $m) {
			
			//setup variables
			$movie_id = fix_movie_id($m['movie_id']);
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			$poster = build_poster_url($movie_id, $m['hiphotos']);
			$attribute = $m['attribute'];
			
			//print out the attribute
			if ($attribute != '') {
				$attribute = " ($attribute)";
			} else {
				$attribute = "";
			}
			
			//write out HTML
			$html .= "<div class='cimg'>
					  	<a href='/movie/$movie_id/$url_name'>
					  	<img src='$poster' />
					  	<div class='image_title'>
					  		<a href='/movie/$movie_id/$url_name'>$name$attribute</a>
					  	</div>
					 </div>";
		}
		
		return $html;
		$ms = NULL;
	}
	
	/**
	 * Build coming soon list for carousel poster images.
	 * 
	 * @param $db
	 * @param $site_id
	 * @return String $html
	 */
	function html_chain_coming_soon_posters($db, $site_id, $choice_id) {
		$html = "";
		$ms = fxp_get_coming_soon($db, $site_id, $choice_id);
		foreach ($ms as $m) {
			
			//setup variables
			$movie_id = fix_movie_id($m['movie_id']);
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			$poster = build_poster_url($movie_id, $m['hiphotos'], '');
			$attribute = $m['attribute'];
			
			//print out the attribute
			if ($attribute != '') {
				$attribute = " ($attribute)";
			} else {
				$attribute = "";
			}

			//write out HTML
			$html .= "<div class='cimg'>
					  	<a href='/movie/$movie_id/$url_name'>
					  	<img src='$poster' />
					  	<div class='image_title'>
					  		<a href='/movie/$movie_id/$url_name'>$name$attribute</a>
					  	</div>
					 </div>";
		}
		
		return $html;
		$ms = NULL;
	}
	
	/**
	 * Build coming soon list for navigation drop down.
	 * 
	 * @param $db
	 * @param $site_id
	 * @return String $html
	 */
	 function html_coming_soon_nav($db, $site_id, $choice_id) {
	 	$html = "";
	 	$ms = fxp_get_coming_soon($db, $site_id, $choice_id);
		foreach ($ms as $m) {
			
			//setup variables
			$movie_id = fix_movie_id($m['movie_id']);
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			
			//write out HTML
			$html .= "<li><a href='/movie/$movie_id/$url_name'>$name</a></li>\r";
		}
		
		return $html;
		$ms = NULL;
	 }
	 
	 /**
	  * Build coming soon list for righthand side element.
	  * 
	  * @param $db
	  * @param $site_id
	  * @return String $html
	  */
	 function html_coming_soon_grid($db, $site_id, $choice_id) {
	 	$html = "";
		$ms = fxp_get_coming_soon($db, $site_id, $choice_id);
		foreach ($ms as $m) {
			
			//setup variables
			$movie_id = fix_movie_id($m['movie_id']);
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			$still = movie_get_still($db, $m['movie_id']);
			$release = date('F j', strtotime($m['Release']));
			
			//write out HTML
			$html .= "<div class='coming-soon-movie'>
							<a href='/movie/$movie_id/$url_name'>
								<img src='$still' />
								<h3>$name</h3>
								<p>$release</p>
							</a>
						</div>";
		}
		
		return $html;
		$ms = NULL;
	 }
	 
	 /** 
	  * Build showtimes content for index page.
	  * 
	  * @param $db
	  * @param $house_id
	  * @param $date YYYY-MM-DD
	  * @return String $html 
	  */
	 function html_house_showtimes($db, $site_id, $house_id, $date) {
	 	$html = "";
	 	$data = house_get_showtimes($db, $site_id, $house_id, $date);
		foreach ($data as $st) {
			
			//setup variables
			$movie_id = fix_movie_id($st['movie_id']);
			$times = build_showtimes_string(build_showtimes($house_id, $st, $date), ', ');
			$name = fix_movie_name($st['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			$mpaa = trim($st['mpaa']);
			$comment = trim($st['comment']);
			
			//add tags to teh comment if it exists
			if (!empty($comment)) {
				$comment = "<p><b>$comment</b></p>";
			} else {
				$comment = "";
			}
			
			//write out HTML
			$html .= "<div class='showtime'>
						<h3><a href='/movie/$movie_id/$url_name'>$name ($mpaa)</a></h3>
						$comment
						<p>$times</p>
					 </div>";
		}
		
		return $html;
		$data = NULL;
	 }
	 
	 /**
	 * Build now playing list for carousel poster images.
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $date YYYY-MM-DD
	 * @return String $html
	 */
	function html_house_now_playing_posters($db, $house_id, $date) {
		$html = "";
		$ms = house_get_now_playing($db, $house_id, $date);
		foreach ($ms as $m) {
			
			//setup variables
			$movie_id = fix_movie_id($m['movie_id']);
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			$poster = build_poster_url($movie_id, $m['hiphotos'], '');
			$attribute = $m['attribute'];
			
			//print out the attribute
			if ($attribute != '') {
				$attribute = " ($attribute)";
			} else {
				$attribute = "";
			}
			
			//write out HTML
			$html .= "<div class='cimg'>
					  	<a href='/movie/$movie_id/$url_name'>
					  	<img src='$poster' />
					  	<div class='image_title'>
					  		<a href='/movie/$movie_id/$url_name'>$name.$attribute</a>
					  	</div>
					  </div>";
		}
		
		return $html;
		$ms = NULL;
	 }
	 
	 /** 
	  * Build showtimes content for location page.
	  * Includes extra movie details
	  *	
	  * 
	  * @param $db
	  * @param $house_id
	  * @param $date YYYY-MM-DD
	  * @param $ticketing true or false
	  * @param $delimeter the text
	  * @return String $html 
	  */
	 function html_house_showtimes_detailed($db, $site_id, $house_id, $date, $ticketing, $delimeter) {
	 	$html = "";
		$i = 0;
	 	$raw_data = house_get_showtimes($db, $site_id, $house_id, $date);
	 	$soldouts = house_get_perfs_soldout($db, $house_id, $date);
	 	$data = build_showtime_rows($house_id, $raw_data, $soldouts, $ticketing);

		if (count($data) == 0) {
			return '<h3 style="width: 400px;margin: 0 auto; display: block;">Sorry, no showtimes available for this date</h3></div>';
		}

		foreach ($data as $key => $st) {
			if (count($st['showtimes']) == 0) {
				continue;
			}
			//set some variables
			$movie_id = fix_movie_id($st["movie_id"]);
			$name = fix_movie_name($st["name"]);
			$url_name = url_name($name) . "-Trailer-and-Info";
			$mpaa = trim($st["mpaa"]);
			$runtime = fix_movie_runtime($st["runtime"]);
			$poster = ($st['posterImage'] != '') ? fxp_build_poster_url($site_id, $st['posterImage']) : build_poster_url($movie_id, $st['hiphotos']);
			$moviepage = "/movie/$movie_id/$url_name"; 
			$trailer = build_trailer_url($movie_id, $st['flv_high']);

			$times_rows = '';
			foreach ($st['showtimes'] as $showtimes_row) {
				$times = '';
				usort($showtimes_row['times'], function ($a, $b) {
					return strcmp($a['sort'], $b['sort']);
				});
				foreach ($showtimes_row['times'] as $time) {
					$times .= $time['html'];
				}

				$allow_passes = (stripos($showtimes_row['allowpass'], 'n') !== false) ? '<div id="allow-passes">No Passes allowed</div>' : '';
				$comment = build_attributes($house_id, $showtimes_row['comment']);
				$times_rows .= '
					<div id="comment">
						<div>' . $comment . '</div>
						' . $allow_passes . '
						<span class="times">' . $times . '</span>
					</div>
				';
			}
			
			$html .= '
				<div id="showtimes_movie">
					<div id="poster">
						<a href="' . $moviepage . '">
							<img src="' . $poster . '" class="poster"/>
						</a>
					</div>
					<div id="info">
						<a href="' . $moviepage . '" class="name">' . $name . '</a>
						<span class="mpaa">Rated ' . $mpaa . '</span><br>
						<span class="runtime">' . $runtime . '</span>
						' . $times_rows . '
					</div>
					<div class="clearfix"></div>
				</div>
			';
				
		}	
			
		return $html;
	 }
	 
	  /**
* Extract list of theatre amenities from semicolon delimited string
* 
* @param $amenities
*
* @return String $html
*/
function html_get_amenities($amenities) {
$html = "";
 
//translate icon placeholders
$text = str_replace("{3D}", "<img src='/img/amenities/3d.png' />            ", $amenities);
$text = str_replace("{accessible}", "<img src='/img/amenities/accessible.png' />", $text);
$text = str_replace("{audio}", "<img src='/img/amenities/audioDev.png' />", $text);
$text = str_replace("{listen}", "<img src='/img/amenities/listenDev.png' />", $text);
$text = str_replace("{bar}", "<img src='/img/amenities/fullBar.png' />", $text);
$text = str_replace("{beerWine}", "<img src='/img/amenities/beerWine.png' />", $text);
$text = str_replace("{dbox}", "<img src='/img/amenities/dBox.png' />", $text);
$text = str_replace("{extreme}", "<img src='/img/amenities/extreme.png' />", $text);
$text = str_replace("{food}", "<img src='/img/amenities/food.png' />", $text);
$text = str_replace("{imax}", "<img src='/img/amenities/IMax.png' />", $text);
$text = str_replace("{kiosk}", "<img src='/img/amenities/kiosk.png' />", $text);
$text = str_replace("{mobile}", "<img src='/img/amenities/mobileTIX.png' />", $text);
$text = str_replace("{recliners}", "<img src='/img/amenities/recline.png' />", $text);
$text = str_replace("{reserved}", "<img src='/img/amenities/reserved.png' />", $text);
$text = str_replace("{stadium}", "<img src='/img/amenities/stadium.png' />", $text);
$text = str_replace("{bowling}", "<img src='/img/amenities/bowling.png' />", $text);

 
//now split into an array
$arr = explode(";", $text);
 
//loop through and add list tags
foreach ($arr as $a) {
$html .= "<li>$a</li>";
}
 
//return HTML
 
return $html;
$features = NULL;
}

	 
	 /** 
	  * Build string of prices from FXP
	  * 
	  * @param $db
	  * @param $house_id
	  * @return String $html 
	  */
	 function html_house_prices($db, $house_id) {
	 	$html = "";
	 	$data = house_get_prices($db, $house_id);
		
		foreach ($data as $p) {
			
			//setup variables
			$category = array();
			$price = array();
			$category = trim($p["price_daypart"]);
			
			//print out the header fo rthis price section
			$html .= "<span class='price_category'>$category</span><br>";
			
			//extract the price fields into an array
			for ($i=1; $i<=10; $i++) {
				$field[$i] = trim($p["price_cat".$i]);
				$price[$i] = trim($p["price_amount".$i]);
				
				//add prices to the HTML
				if ($field[$i] != "") {
					
					//if the field ha sa semicolon, we have a disclaimer
					if (strpos($field[$i], ';') > 0) {
						$field_new = split(';',$field[$i]);
						$field[$i] = $field_new[0] . "<br><span class='disclaimer'>" . $field_new[1] . "</span>";
					}
					
					if (trim($price[$i]) != '') {
						$html .= "<span class='price'>" . $price[$i] . "</span> -";
					}
					$html .= "<span class='field'>" . $field[$i] . "</span> <br>";
				}
			}
			
		}
		
		//print out the HTML
		return $html;
	 }
	 
	 /** 
	  * Build showtimes content for print showtimes page.
	  * 
	  * @param $db
	  * @param $house_id
	  * @param $date YYYY-MM-DD
	  * @return String $html 
	  */
	 function html_house_print_showtimes($db, $site_id, $house_id, $date) {
	 	$html = "";
		$data = house_get_showtimes($db, $site_id, $house_id, $date);
		
		//Print a message if no showtiems exist
		if (empty($data)) {
			$html = '<p>Sorry, no showtimes available for this date</p>';
		} else {
			foreach($data as $m) {
				
				$name = fix_movie_name($m['name']);
				$showtimes = build_showtimes_string(build_showtimes($house_id, $m, $date), ', ');
				
				//only print the HTML if the showtiems string is not empty
				if (strlen($showtimes) > 0) {
					
					$comment = trim($m['comment']);
					
					if (!empty($comment)) {
						$comment = "<i>Available in: $comment</i><br />";
					}
					
					//write out HTML
					$html .= "<p>
							    <b>$name</b><br />
								$comment
								$showtimes
							</p>";
				}
			}
		}
		
		return $html;
		$data = NULL;
	 }
	 
	 /**
	  * Build showtimes content for movie page.
	  * 
	  * @param $db
	  * @param $house_id
	  * @param $movie_id
	  * @param $date YYYY-MM-DD
	  * @return String $html
	  */
	 function html_movie_showtimes($db, $house_id, $movie_id, $date) {
	 	$html = "";
		$data = movie_get_showtimes($db, $house_id, $movie_id, $date);
		
		if (!empty($data)) {
			
			//setup variables
			$comment = trim($data['comment']);
			$times = build_showtimes_string(build_showtimes($house_id, $data, $date), ', ');
			
			//add tags to comment if there is one
			if (!empty($comment)) {
				$comment = "<p><b>$comment</b></p>";
			} else {
				$comment = "";
			}
			
			//write out HTML
			$html = "$comment<p>$times</p>";	
		}
		return $html;
		$data = NULL;
	 }
	 
	/**
	  * Build showtimes content for movie page.
	  * 
	  * @param $db
	  * @param $site_id
	  * @param $movie_id
	  * @param $ticketing
	  * @param $delimeter
	  * @param $date YYYY-MM-DD
	  * @return String $html
	  */
	 function html_movie_showtimes_chain($db, $site_id, $movie_id, $ticketing, $delimeter, $date) {
	 	$html = "";
	 	$i = 0;
		$data = movie_get_showtimes_chain($db, $site_id, $movie_id, $date);
	
		if (empty($data)) {
			$html .= "<div class='theater'>
					    No showtimes available<br>on this date.
					 </div>";	
		} else {
			foreach ($data as $h) {
				$house_id = $h["house_id"];
				$show_house_id = $h["show_house_id"];
				$name = trim($h['name']);
				$url_name = url_name($name) . "-Showtimes";
				
				//determine if ticketing or not
				if ($ticketing) {
					$times = build_showtimes_string(build_showtimes_ticketing($house_id, $h, $date), $delimeter);
				} else {
					$times = build_showtimes_string(build_showtimes($house_id, $h, $date), $delimeter);
				}
				
				//start the first div
				if ($i == 0) {
					$html .= "<div id='$house_id' class='theater'>
							  <span class='name'><a href='/location/$house_id/$url_name'>$name</a></span>";
				}
				
				//if house_id does not match old house_id, close out prev div and start new one
				if ($name_old != $name && $i != 00) {
					$html .= "</div>
							  <div id='$house_id' class='theater'>
							  <span class='name'><a href='/location/$house_id/$url_name'>$name</a></span>";
				}
								
				//add tags to comment if there is one
				if (!empty($h['comment'])) {
					$comment = $h['comment'];
				} else {
					$comment = '';
				}
				
				//print out showtimes
				$html .= "<span class='times'>$times</span>
						  <span class='comment'>$comment</span>";	
				
				$name_old = $name;
				$i++;
			}
			
			//close out last div
			$html .= "</div>";
		}
		
		return $html;
		$data = NULL;
	 }

	 
	 /**
	  * Build string of movie versions
	  * 
	  * @param $db
	  * @param $movie_id
	  * @param $site_id
	  * @return String $html
	  */
	 function html_movie_versions($db, $movie_id, $site_id, $delimeter) {
		$i = 0;
	 	$html = "";
		$data = movie_get_versions($db, $movie_id, $site_id);
		if (!empty($data)) {
		
			$html = 'Also available in ';
			
			//loop through the versions and make a string
			foreach ($data as $version => $v) {
				$html .= $v . $delimeter;
				$i++;
			}
		}
		
		//remove trailing seperation character and return
		return substr($html, 0, strpos($html, $delimeter));
		$data = NULL;
	 }
	 
	 /**
	  * Build movies content for movies page.
	  * 
	  * @param $db
	  * @param $house_id
	  * @param $date YYYY-MM-DD
	  * @return String $html
	  */
	 function html_movies_grid($db, $house_id, $date) {
	 	$html = "";
	 	$ms = house_get_now_playing($db, $house_id, $date);
		foreach ($ms as $m) {
			
			//setup variables
			$photo = build_poster_url(fix_movie_id($m['movie_id']), $m['hiphotos']);
			$movie_id = fix_movie_id($m["movie_id"]);
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			
			//write out HTML
			$html .= "<div class='movie'>
						<a href='/movie/$movie_id/$url_name'>
							<img src='$photo' />
							<h3>$name</h3>
						</a>
					</div>";
		}
		
		return $html;
		$ms = NULL;
	 }
	 
	 /**
	  * Build 3D movies content for 3D movies page.
	  * 
	  * @param $db
	  * @param $house_id
	  * @param $date YYYY-MM-DD
	  * @return String $html
	  */
	 function html_movies_grid_3D($db, $house_id, $date) {
	 	$html = "";
		$ms = house_get_now_playing_3D($db, $house_id, $date);
		foreach ($ms as $m) {
		
			//setup variables
			$photo = build_poster_url(fix_movie_id($m['movie_id']), $m['hiphotos']);
			$movie_id = fix_movie_id($m["movie_id"]);
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name) . "-Trailer-and-Info";
			
			//write out HTML
			$html .= "<div class='movie'>
						<a href='/movie/$movie_id/$url_name'>
							<img src='$photo' />
							<h3>$name</h3>
						</a>
					</div>";
		}
		return $html;
		$ms = NULL;
	 }
	 
	 /** 
	  * Build full list of houses playing a movie
	  * with house not playing grayed out
	  * 
	  * @param $db
	  * @param $chain_id
	  * @param $site_id
	  * @param $movie_id
	  * @param $date YYYY-MM-DD
	  * @return String $html 
	  */
	 function html_houses_playing_movie($db, $site_id, $movie_id, $date) {
	 	$html = "";
	 	$houses = movie_get_houses($db, $site_id, $movie_id, $date);

		foreach ($houses as $h) {
			
			//setup variables
			$house_id = fix_movie_id($h['house_id']);
			$h_movie_id = fix_movie_id($h['movie_id']);
			$name = trim($h["name"]);
			$url_name = url_name($name) . "-Showtimes";
			$state = get_state_name($h['state']);
			$showdate = $h["showdate"]; 
			
			//link if we have a showdate, otehrwise, just text
			if ($h["showdate"] != "") {
				$showdate = date("Y-m-d", strtotime($h["showdate"]));
				$html .= "<a href='/location/$house_id/$url_name/$showdate' class='has-times fade'>$name</a>";
			} else {
				$html .= "<p>$name</p>";
			}	
			
			
				
		}
		
		return $html;
		$houses = NULL;
	 }

	 
	 /**
	  * Build Form that has a <select> dropdown with showdates for a particular house
	  * 
	  * @param $db
	  * @param $house_id
	  * @param $date YYYY-MM-DD
	  * @return String $html
	  */
	 function html_house_showdates($db, $house_id, $date) {
	 	$html = "";
		$today = date('Y-m-d', strtotime('today'));
		$dates = house_get_showdates($db, $house_id, $today);
		$dates = $dates["showdates"];
		
		//start <form>
		$html = '<form id="frmShowdate">';
		
		//build HTML only if we found showdates for this house
		if (!empty($dates)) {
			
			//start <select> field
			$html .= "<select class='select_styled' name='date' onchange='this.form.submit();'>";
			
			//make the querystring date first in the dropdown if there is one
			if (!empty($_GET['date'])) {
				$html .= "<option value='".$date."'>".date('l n/j', strtotime($date))."</option>";
			}
			
			//loop through found showdates
			foreach($dates as $d) {
				
				//convert to long date
				$long_date = date('l n/j', strtotime($d));
				
				//Print "Today" if the date is 'today'
				if ($d == $today) {
					$html .=  "<option value='$d'>Today</option>";
				} else {
					$html .=  "<option value='$d'>$long_date</option>";
				}
			}
			
			//end <select>
			$html .= "</select>";
		} else {
			$html .= "No showtimes available";
		}
		
		//close <form>
		$html .= '</form>';
		
		return $html;
		$dates = NULL;
	 }
	 
	 /**
	  * Build Form that has a text div with showdates for a particular house
	  * 
	  * @param $db
	  * @param $house_id
	  * @param $date YYYY-MM-DD
	  * @return String $html
	  */
	 function html_house_showdates_text($db, $house_id, $today, $name) {
		$html = "";
		
		//if date is passed, use it. Otherwise, it is today
		if ($_GET["date"] != "") {
			$date_selected = $_GET["date"];
		} else {
			$date_selected = $today;
		}
		
		//print out 3 letter abbreviation buttons for all days after 'today'
		for($i = 0; $i <= 5; $i++) {
		
			$new_date = date("Y-m-d", strtotime($today . ' +' . $i . 'days'));
			$day = date('D', strtotime($new_date));
			
			//is the querystring date equal to this date? Add selected class if so
			if (strtotime($date_selected) == strtotime($new_date)) {
				$class = " class='selected'";
			} else {
				$class = '';
			}
			
			//Today
			if ($i == 0) {
				$html .= "<a href='/location/$house_id/$name/$today' $class class='fade'>Today</a>";
			//Next 6 days
			} else {
				$new_date = date("Y-m-d", strtotime($today . ' +' . $i . 'days'));
				$day = date('D', strtotime($new_date));
				
				//write out data button				
				$html .= "<a href='/location/$house_id/$name/$new_date' $class class='fade'>$day</a>";
			}
		}
		
		//More button
		$html .= "<form id='form' action=''>
					<input id='datepicker' type='text' name='date' value='MORE' readonly/>
				</form>";
		
		$html .= '';
		
		return $html;
	  }
	 
	  /**
	  * Build Form that has a <select> dropdown with showdates for a particular house
	  * 
	  * @param $db
	  * @param $house_id
	  * @param $date YYYY-MM-DD
	  * @param $movie_id
	  * @return String $html
	  */
	 function html_movie_showdates($db, $house_id, $movie_id, $date) {
	 	$html = "";
		$today = date('Y-m-d', strtotime('today'));
		$dates = house_get_movie_showdates($db, $house_id, $movie_id, $today);
		
		//start <form>
		$html = '<form id="frmShowdate" action="" method="get">
				 <input type="hidden" name="house_id" value="'.$house_id.'" />';
		
		//we found dates!
		if (!empty($dates)) {
			
			//start <select>
			$html .= "<select class='select_styled' name='date' onchange='this.form.submit();'>";
			
			//loop through the found showdates
			foreach($dates as $d) {
				
				//convert to long date
				$long_date = date('l n/j', strtotime($d));
				
				//Print "Today" if the date is 'today'
				if ($d == $today) {
					$html .=  "<option value='$d'>Today</option>";
				} else {
					$html .=  "<option value='$d'>$long_date</option>";
				}

			}
			
			//end <select>
			$html .= "</select>";
		} else {
			$html .= "No showtimes available";
		}
		
		//end <form>
		$html .= '</form>';
		
		return $html;
		$dates = NULL;
	 }
	 
	 /**
	  * Build DIVs to with still and movie name for a rotation script
	  * 
	  * @param $db
	  * @param $house_id
	  * @param $date YYYY-MM-DD
	  * @return String $html
	  */
	 function html_chain_rotater_DBOX($db, $chain_id, $date) {
	 	$html = "";
		$ms = chain_get_now_playing_dbox($db, $chain_id, $date);
		foreach ($ms as $m) {
			
			//setup variables
			$name = fix_movie_name($m['name']);
			$still = movie_get_still($db, fix_movie_id($m['movie_id']));
			
			//write out HTML
			$html .= "<div class='dbox_movie'>
						<img src='$still' /><br>
						<h3>$name</h3>
					</div>";
		}
		
		return $html;
		$ms = NULL;
	 }
	 
	 /**
	  * Build <select> drop down with months
	  * 
	  * @param $value
	  * @return String $html
	  */
	 function html_select_months($name,$value) {
	 	$html = "";
		$html = "<select id='$name' name='$name'>
					<option value=''></option>";
		
		//loop through all 12 months and right out full month name
		for ($i = 1; $i <= 12; $i++) {
			
			//get the month name
			$month_name = substr(date("F", mktime(0, 0, 0, $i)),0,3);
			
			//mark this as selected if we passed in a certain value
			if ($i == intval($value)) {
				$selected = "selected";
			} else {
				$selected = "";
			}
			
			//write out HTML
			$html .= "<option value='$i' $selected>$month_name</option>";
		}
		
		$html .= "</select>";
		return $html;
	 }
	 
	 /**
	  * Build <select> drop down with days
	  * 
	  * @param $value
	  * @return String $html
	  */
	 function html_select_days($name,$value) {
	 	$html = "";
		$html = "<select id='$name' name='$name'>
					<option value=''></option>";
		
		//loop through 31 days
		for ($i = 1; $i <= 31; $i++) {
			
			//mark this as selected if we passed in a certain value
			if ($i == intval($value)) {
				$selected = "selected";
			} else {
				$selected = "";
			}
			
			//write out HTML
			$html .= "<option value='$i' $selected>$i</option>";
		}
		
		$html .= "</select>";
		return $html;
	 }
	 
	  /**
	  * Build <select> drop down with years
	  * 
	  * @param $value
	  * @return String $html
	  */
	 function html_select_years($name,$value,$required) {
	 	$html = "";
		$html = "<select id='$name' name='$name' class='$required'>
					<option value=''></option>";
		
		//loop through past X # of years (90 by default)
		for ($i = 0; $i <= 90; $i++) {
			
			//setup variables
			$current_year = date('Y', strtotime("now"));
			$year = date('Y', strtotime("-$i year"));
			
			//mark this as selected if we passed in a certain value
			if ($year == intval($value)) {
				$selected = "selected";
			} else {
				$selected = "";
			}
			
			//write out HTML
			$html .= "<option value='$year' $selected>$year</option>";
		}
		
		$html .= "</select>";
		return $html;
	 }
	 
	 /**
	 * Build list of movies for a house for select drop-down.
	 * 
	 * @param $chain_id
	 * @return String $html
	 */
	function html_house_movies_select($db, $house_id, $date) {
		$html = "";
		$movie = house_get_now_playing_all($db, $house_id, $date);
	
		foreach ($movie as $m) {
			
			//setup variables
			$movie_id = fix_movie_id($m['movie_id']);
			$name = fix_movie_id($m['name']);
			$url_name = url_name($name);
									
			//write out the theater
			$html .= "<option value='/movie/$movie_id/$url_name'>$name</option>\r";
		}
		
		return $html;
		$hs = NULL;
	}
	
	/**
	 * Build list of movies for a house for select drop-down.
	 * 
	 * @param $chain_id
	 * @return String $html
	 */
	function html_site_movies_select($db, $site_id, $date) {
		$html = "";
		$movies = fxp_get_all_movies($db, $site_id, $date);
	
		foreach ($movies as $m) {
			
			//setup variables
			$movie_id = fix_movie_id($m['movie_id']);
			$name = fix_movie_name($m['name']);
			$url_name = url_name($name);
									
			//write out unique movies only
			if ($movie_id_old != $movie_id) {
				$html .= "<option value='/movie/$movie_id/$url_name'>$name</option>\r";
			}
			
			$movie_id_old = $movie_id;
		}
		
		return $html;
		$hs = NULL;
	}
	
	/**
	 * Build list of movies for a house for select drop-down.
	 * 
	 * @param $chain_id
	 * @return String $html
	 */
	function html_house_movie_date_select($db, $house_id, $movie_id, $date) {
		$html = "";
		$dates = movie_get_house_showdates($db, $house_id, $movie_id, $date);
		$html .= "<option value=''>Select a Date</option>\r";
		foreach ($dates as $d) {
			
			//setup variables
			$date = date('l, F j', strtotime($d['showdate']));
			$date_val = date('n/j/Y', strtotime($d['showdate']));
									
			//write out the theater
			$html .= "<option value='$date_val'>$date</option>\r";
		}

		return $html;
		$dates = NULL;
	}
	
	/**
	 * Build list of movies for a house for select drop-down.
	 * 
	 * @param $chain_id
	 * @return String $html
	 */
	function html_house_movie_showtime_select($db, $house_id, $movie_id, $date) {
		$html = "";
		$showtimes = array();
		$times = movie_get_showtimes($db, $house_id, $movie_id, $date);
		$html .= "<option value=''>Select a Showtime</option>\r";
		foreach ($times as $t) {
			
			//build current times array and merge with main array
			$new_showtimes = build_dropdown_showtimes($house_id, $t, $date);
			$showtimes = array_merge($showtimes, $new_showtimes);					
		}
		
		//sort the times
		ksort($showtimes);
		
		//loop through new array and write out HTML
		foreach ($showtimes as $s) {
			
			//write out the time
			$html .= "<option value='" . $s["url"] . "'>" . $s["showtime"] . $s["comment"] . "</option>\r";
		}
		
		return $html;
		$dates = NULL;
	}
	 
	 /**
	 * Build list of houses in a chain for navigation drop-down.
	 * 
	 * @param $name
	 * @param $value
	 * @param $required
	 * @param $chain_id
	 * @param $site_id
	 * @param $config
	 * @param $db
	 * @return String $html
	 */
	function html_select_houses($name,$value,$required,$chain_id,$site_id,$config,$db) {
		$html = "";
		$hs = chain_get_houses($db, $chain_id, $site_id);
		
		//start <select>
		$html = "<select id='$name' name='$name' class='$required'>
					<option value=''>Select</option>";
		
		//loop through all houses in the chain
		foreach ($hs as $h) {
			
			//setup variables
			$city = trim($h["city"]);
			$state = trim($h["state"]);
			$name = trim($h["name"]);
			
			if ($config == 'city') {
				$house = "$city, $state";
			} else {
				$house = $name;
			}
			
			
			//mark this as selected if we passed in a certain value
			if ($house == $value) {
				$selected = "selected";
			} else {
				$selected = "";
			}
			
			//write out HTML
			$html .= "<option value='$house' $selected>$house</option>";
		}
		
		$html .= "</select>";
		return $html;
	}
	
	/**
	 * Write out list of FXP carousel images
	 * 
	 * @param $site_id
	 * @param $db
	 * @return String $html
	 */
	function html_fxp_carousel_images($db,$site_id) {
		$html = "";
		$carousel = fxp_get_carousel($db, $site_id);
		
		foreach($carousel as $c) {
			
			//setup variables
			$image = trim($c['image']);
			$url = trim($c['url']);
			$target = $c['target'];
			
			//Wrap the image in <a> tags if there was a URL entered
			if ($url != "") {
				$image = "<a href='$url' target='$target'><img src='$image' /></a>";
			} else {
				$image = "<img src='$image' />";
			}
			
			//write out HTML
			$html .= "<div class='carousel_image'>$image</div>";
		}
		
		return $html;
		$carousel = NULL;
	}
	
	/**
	 * Write out FXP page content for each location
	 * 
	 * @param $house_id
	 * 
	 * @return String $html
	 */
	 
	 function get_fxp_message($site_id, $house_id) {
		 
		 //house_id => fxp_page
		 $pages = array(2537 => 1725, 8334 => 1726, 5477 => 1727);
		 
		 //get the fxp page and return the content
		 return fxp_get_page($site_id, $pages[$house_id]);
	 }
	
	
	/**
	 * Outputs the thumbnail of a facebook 
	 * 
	 * @param $page_name (Facebook page name)
	 * @param $album_id (Facebook album ID)
	 * @param $photo_page (your page that shows the photo gallery)
	 */
	function html_facebook_album($page_name, $album_id, $photo_page) {
	
		 //use Facebook Graph API to retrieve albums' ID and count (no of images in album)
		 $string1 = file_get_contents('https://graph.facebook.com/'.$page_name.'/albums?fields=id,count');
	
		 //the Json file with the data contains the word "count" which is a reserved word in PHP, so I replaced it with "countx" (I know- very imaginative)
		 $string = str_replace ("count", "countx", $string1);
	
		 //decoding the Json feed
		 $jdata = json_decode($string);
	
		 //get the information about this album from Facebook Graph API
		 $string2 = file_get_contents('https://graph.facebook.com/fql?q=SELECT%20name,%20created%20FROM%20album%20WHERE%20owner='.$page_name.'%20and%20object_id='.$album_id.'');
	
		 //decode the JSON string and output the first album it finds to an array
		 $adata = json_decode($string2);
		 $album_name = $adata->data[0]->name; 
		 
		 //output the cover thumbnail and link to full facebook album
		 echo "<a href='$photo_page?albumid=$album_id&albumname=$album_name' class='facebook_lightbox' data-fancybox-type='iframe' width='800px' height='600px'>
				<img src='https://graph.facebook.com/".$album_id."/picture?type=album'/>
				<span class='FB_pic_label'>Click to view photo gallery</span>
			   </a>";
	}
	
	/**
	 * Write out a string of nav breadcrumbs
	 * 
	 * @param $seperator
	 * @param $home
	 * @return String $html
	 */
	function html_nav_breadcrumbs($separator = ' &raquo; ', $home = 'Home') {
		// This gets the REQUEST_URI (/path/to/file.php), splits the string (using '/') into an array, and then filters out any empty values
		$path = array_filter(explode('/', parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH)));
		
		//build our "base URL"
		$base = 'http://' . $_SERVER['HTTP_HOST'] . '/';
		
		// This will build our "base URL" ... Also accounts for HTTPS :)
		//$base = ($_SERVER['HTTPS'] ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST'] . '/';
	
		// Initialize a temporary array with our breadcrumbs. (starting with our home page, which I'm assuming will be the base URL)
		$breadcrumbs = Array("<span class='crumb'><a href=\"$base\">$home</a></span>");
	
		// Find out the index for the last value in our path array
		$last = end(array_keys($path));
	
		// Build the rest of the breadcrumbs
		foreach ($path AS $x => $crumb) {
			// Our "title" is the text that will be displayed (strip out .php and turn '_' into a space)
			$title = ucwords(str_replace(Array('.php', '_'), Array('', ' '), $crumb));
	
			// If we are not on the last index, then display an <a> tag
			if ($x != $last)
				$breadcrumbs[] = "<span class='crumb'><a href=\"$base$crumb\">$title</a></span>";
			// Otherwise, just display the title (minus)
			else
				$breadcrumbs[] = "<span class='crumb'>$title</span>";
		}
	
		// Build our temporary array (pieces of bread) into one big string :)
		return implode($separator, $breadcrumbs);
	}
	
 	/**
	 * Gets a two dimensional array of all movies 
	 * and theaters playing at or a part of a website
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $search
	 *
	 * @return Array $movies[numeric][key] a two dimensional array
	 */
	function html_search_movies_and_houses($db, $site_id, $search) {
		
		//search the database
		$results = search_movies_and_houses($db, $site_id, $search);
		
		//no data?
		if (empty($results)) {
			$data[] = array('label' => "No Results Found", 'value' => "NULL", 'category' => "");
		} else {
			//loop through results and add field to array
			foreach ($results as $r) {
				$id = fix_movie_id($r["id"]);
				$name = fix_movie_name($r["name"]);
				$category = trim($r["category"]);
				
				//determine the page based onteh category
				if ($category == "movies") {
					$page = "movie";
					$url_name = url_name($name) . "-Trailer-and-Info";
				} else {
					$page = "location";
					$url_name = url_name($name) . "-Showtimes";
				}
				
				$url = "/$page/$id/$url_name";
				
				//add data to array
				$data[] = array('label' => "$name", 'value' => $url, 'category' => $category);
			}
		}
		
		//return JSON data
		echo json_encode($data);
	}
	
	/**
	 * Generate Sitemap XML
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $chain_id
	 * @return XML $html
	 */
	 function xml_generate_sitemap($db, $chain_id, $site_id) {
		 $xml = "";
		 
		//set the root directory
		$root = $_SERVER["DOCUMENT_ROOT"];
		$host = "http://" . $_SERVER['HTTP_HOST'];
		
		//excluded dynamic pages
		$exclude = array(".","..","404.php","error.php","index.php","template.php","movie.php","location.php","trailer.php","web.config");
		
		//start the XML
		$xml = '<?xml version="1.0" encoding="UTF-8"?>
					<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9"
						    xmlns:image="http://www.google.com/schemas/sitemap-image/1.1" 
							xmlns:video="http://www.google.com/schemas/sitemap-video/1.1">';
					
		//scan the directory for static pages
		$pages = scandir($_SERVER["DOCUMENT_ROOT"]);
		
		//loop through pages and get subdirectories
		foreach ($pages as $p) {
			$name = strtolower(trim($p));
			$url = $host . "/". str_replace(".php","",$name);
			
			//echo URL node if this meets the proper conditions
			if (strpos($name,".php") != 0 && ! in_array($name,$exclude,true)) {
				$xml .= "<url>
						  	<loc>$url</loc>
						  </url>";
			}
		}
		
		//Dyanmic Location Pages
		$houses = chain_get_houses($db, $chain_id, $site_id);
		
		foreach ($houses as $h) {
			$id = fix_movie_id($h['house_id']);
			$name = trim($h["name"]);
			$url_name = url_name($name) . "-Showtimes";
			$photo = fxp_build_house_photo_url($site_id, $h["PhotoUrl"]);
			$url = "$host/location/$id/$url_name";
			
			$xml .= "<url>
			      		<loc>$url</loc>";
			
			//add poster if it exists
			if ($photo != "") {
				$xml .= "<image:image>
						       <image:loc>$photo</image:loc> 
						    </image:image>";
			}
			
			$xml .= '</url>';
		}
		
		 	 
		//Dynamic Movie Pages
		$movies = sitemap_get_movies($db, $site_id); 
		
		foreach ($movies as $m) {
			$id = fix_movie_id($m["movie_id"]);
			$name = fix_movie_name(trim($m["name"]));
			$url_name = url_name($name) . "-Trailer-and-Info";
			$xml_name = urlencode($name);
			$url = "$host/movie/$id/$url_name";
			$poster = build_poster_url($id, $m["hiphotos"], 'high');
			$trailer = build_trailer_url($id, $m["flv_high"]);
			$bPhotos = trim($m["hiphotos"]);
			$bTrailer = trim($m['flv_high']);
			
			$xml .= "<url>
			      		<loc>$url</loc>";
			
			//add poster if it exists
			if ($bPhotos) {
				$xml .= "<image:image>
						       <image:loc>$poster</image:loc> 
						    </image:image>";
			}
			
			//add trailer if it exists
			if ($bTrailer) {
				$xml .= "<video:video>     
						      <video:content_loc>$trailer </video:content_loc>
						      <video:player_loc allow_embed='yes' autoplay='ap=1'>$trailer</video:player_loc>
							  <video:title>$xml_name Trailer</video:title>  
						      <video:description>
						        Watch the official trailer for $xml_name 
						      </video:description>
					    </video:video>";
			}
					    
			$xml .= '</url>';
		
		}
			  	 
		//End the XML
		$xml .= "</urlset>";
		
		//Cleanup
		$movies = NULL;
		$houses = NULL;
		
		//return the XML
		return $xml;
	 }

/**
 * Builds the image URL for a FilmsXpress carousel.
 *
 * @param $site_id
 * @param $filename
 *
 * @return String a FilmsXpress image URL
 */
function build_carousel_photo_url($site_id, $filename)
{
    if ($filename != "") {
        return "//www.filmsxpress.com/images/Carousel/$site_id/$filename";
    }
}
?>